==> mediawiki_1.12.0.orig.tar.gz: mediawiki-1.12.0/languages/messages/MessagesBm.php <==
<?php
/** Bambara (Bamanankan)
 *
 * @addtogroup Language
 *
 * @author Guaka
 * @author Siebrand
 */

$fallback = 'fr';

$messages = array(
# User preference toggles
'tog-hideminor' => 'Yɛlɛmaliw kura fitini dogo',

# Dates
'sunday'    => 'karidon',
'monday'    => 'ntɛnɛdon',
'tuesday'   => 'taratadon',
'wednesday' => 'arabadon',
'thursday'  => 'alamisadon',
'friday'    => 'jumadon',
'saturday'  => 'sibiridon',
'august'    => 'uti',
'aug'       => 'uti',

# Bits of text used by many pages
'categories'      => 'Nyɛ ka cogoyaw',
'category_header' => 'Nyɛw cogoya kɔnɔ: "$1"',

'article'        => 'Nyɛ',
'qbfind'         => 'Nyini',
'qbedit'         => 'Yɛlɛma',
'qbspecialpages' => 'Nyɛw kɛrɛnkɛrɛnnen',
'mypage'         => "N'ka nyɛ",
'mytalk'         => "N'ka baronyɛ",
'and'            => 'ani',

'help'           => 'Dɛmɛ',
'search'         => 'Nyini',
'history'        => 'Nyɛka tariku',
'history_short'  => 'Tariku',
'info_short'     => 'Kunnafoni',
'edit'           => 'yɛlɛma',
'editthispage'   => 'Nyɛ nin yɛlɛma',
'newpage'        => 'Nyɛ kura',
'specialpage'    => 'Nyɛ kɛrɛnkɛrɛnnen',
'talk'           => 'Baro',
'toolbox'        => 'Minanw',
'userpage'       => 'Utilisateur ka nyɛ',
'imagepage'      => 'Janin ka nyɛ',
'otherlanguages' => 'Kanw wɛrɛ',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'     => 'Kunnafoni',
'currentevents-url' => 'Project:Kunnafoni',
'disclaimers'       => 'Kangari',
'edithelp'          => 'Dɛmɛ',
'mainpage'          => 'Nyɛ fɔlɔ',
'portal'            => 'Jamaje',
'sitesupport'       => 'Banumanke',

'editsection' => 'yɛlɛma',
'hidetoc'     => 'dogo',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'Nyɛ',
'nstab-image'    => 'Janin',
'nstab-help'     => 'Dɛmɛ',
'nstab-category' => 'Cogoya',

# Edit pages
'minoredit'      => 'Yɛlɛma fitini.',
'watchthis'      => 'Nyɛ tulomajɔ',
'newarticle'     => '(Kura)',
'editing'        => '$1 ka yɛlɛmali',
'editingsection' => '$1 ka yɛlɛmali (section)',
'editingcomment' => '$1 ka yɛlɛmali (baro)',

# Search results
'powersearch' => 'Nyini',

# Preferences page
'preferences' => 'Fisayali',
'skin'        => 'Apparence',

# Recent changes
'hide' => 'dogo',

# Image list
'ilsubmit' => 'Nyini',

# Random page
'randompage' => 'Nyɛ min man ni ja',

# Miscellaneous special pages
'popularpages' => 'Nyɛw les plus consultées',
'allpages'     => 'Nyɛw bɛɛ',
'specialpages' => 'Nyɛw kɛrɛnkɛrɛnnen',
'spheading'    => 'Nyɛw kɛrɛnkɛrɛnnen',
'newpages'     => 'Nyɛw kura',
'ancientpages' => 'Nyɛw les plus anciens',
'move'         => 'telun',
'movethispage' => 'Nyɛ telun',

# Watchlist
'watch'         => 'Tulomajɔ',
'watchthispage' => 'Nyɛ tulomajɔ',

# Contributions
'mycontris' => "N'ka contributions",

# Developer tools
'lockconfirm' => 'Awɔ, je confirme que je souhaite verrouiller la base de données.',

# Move page
'movepage'    => 'Nyɛ telun',
'movearticle' => 'Nyɛ telun',
'movepagebtn' => 'Nyɛ telun',

# Attribution
'others' => 'wɛrɛ',

);

==> mediawiki_1.13.3.orig.tar.gz: mediawiki-1.13.3/languages/messages/MessagesBm.php <==
<?php
/** Bambara (Bamanankan)
 *
 * @ingroup Language
 * @file
 *
 * @author Guaka
 * @author לערי ריינהארט
 */

$fallback = 'fr';

$messages = array(
# User preference toggles
'tog-hideminor' => 'Yɛlɛmaliw kura fitini dogo',

# Dates
'sunday'    => 'karidon',
'monday'    => 'ntɛnɛdon',
'tuesday'   => 'taratadon',
'wednesday' => 'arabadon',
'thursday'  => 'alamisadon',
'friday'    => 'jumadon',
'saturday'  => 'sibiridon',
'august'    => 'uti',
'aug'       => 'uti',

# Categories related messages
'category_header' => 'Nyɛw cogoya kɔnɔ: "$1"',

'article'        => 'Nyɛ',
'qbfind'         => 'Nyini',
'qbedit'         => 'Yɛlɛma',
'qbspecialpages' => 'Nyɛw kɛrɛnkɛrɛnnen',
'mypage'         => "N'ka nyɛ",
'mytalk'         => "N'ka baronyɛ",
'and'            => 'ani',

'help'           => 'Dɛmɛ',
'search'         => 'Nyini',
'history'        => 'Nyɛka tariku',
'history_short'  => 'Tariku',
'info_short'     => 'Kunnafoni',
'edit'           => 'yɛlɛma',
'editthispage'   => 'Nyɛ nin yɛlɛma',
'newpage'        => 'Nyɛ kura',
'specialpage'    => 'Nyɛ kɛrɛnkɛrɛnnen',
'talk'           => 'Sɔsɔli',
'toolbox'        => 'Minanw',
'userpage'       => 'Utilisateur ka nyɛ',
'imagepage'      => 'Janin ka nyɛ',
'otherlanguages' => 'Kanw wɛrɛ',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Kunnafoni',
'currentevents-url'    => 'Project:Kunnafoni',
'disclaimers'          => 'Kangari',
'edithelp'             => 'Dɛmɛ',
'mainpage'             => 'Nyɛ fɔlɔ',
'mainpage-description' => 'Nyɛ fɔlɔ',
'portal'               => 'Jamaje',

'editsection' => 'yɛlɛma',
'hidetoc'     => 'dogo',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'Nyɛ',
'nstab-image'    => 'Janin',
'nstab-help'     => 'Dɛmɛ',
'nstab-category' => 'Cogoya',

# Edit pages
'minoredit'      => 'Yɛlɛma fitini.',
'watchthis'      => 'Nyɛ tulomajɔ',
'newarticle'     => '(Kura)',
'editing'        => '$1 ka yɛlɛmali',
'editingsection' => '$1 ka yɛlɛmali (section)',
'editingcomment' => '$1 ka yɛlɛmali (baro)',

# Search results
'powersearch' => 'Nyini',

# Preferences page
'preferences' => 'Fisayali',
'skin'        => 'Apparence',

# Recent changes
'hide' => 'dogo',

# Random page
'randompage' => 'Nyɛ min man ni ja',

# Miscellaneous special pages
'popularpages' => 'Nyɛw les plus consultées',
'newpages'     => 'Nyɛw kura',
'ancientpages' => 'Nyɛw les plus anciens',
'move'         => 'telun',
'movethispage' => 'Nyɛ telun',

# Special:AllPages
'allpages' => 'Nyɛw bɛɛ',

# Special:Categories
'categories' => 'Nyɛ ka cogoyaw',

# Watchlist
'watch'         => 'Tulomajɔ',
'watchthispage' => 'Nyɛ tulomajɔ',

# Contributions
'mycontris' => "N'ka contributions",

# Developer tools
'lockconfirm' => 'Awɔ, je confirme que je souhaite verrouiller la base de données.',

# Move page
'move-page-legend' => 'Nyɛ telun',
'movearticle'      => 'Nyɛ telun',
'movepagebtn'      => 'Nyɛ telun',

# Attribution
'others' => 'wɛrɛ',

# Special:NewImages
'ilsubmit' => 'Nyini',

# Special:SpecialPages
'specialpages' => 'Nyɛw kɛrɛnkɛrɛnnen',

);
